@@ -642,7 +642,7 @@ def seek_all_images(img, channels = 3):
             break
         i += 1
 
-# tensor of shape (frame, channels, height, width) -> gif
+# tensor of shape (channels, frames, height, width) -> gif
 
 def video_tensor_to_gif(tensor, path, duration = 80, loop = 0, optimize = True):
     images = map(T.ToPILImage(), tensor.unbind(dim = 1))
@@ -650,7 +650,7 @@ def video_tensor_to_gif(tensor, path, duration = 80, loop = 0, optimize = True):
     first_img.save(path, save_all = True, append_images = rest_imgs, duration = duration, loop = loop, optimize = optimize)
     return images
 
-# gif -> (frame, channels, height, width) tensor
+# gif -> (channels, frame, height, width) tensor
 
 def gif_to_tensor(path, channels = 3):
     img = Image.open(path)
@@ -662,8 +662,8 @@ class Dataset(data.Dataset):
         self,
         folder,
         image_size,
-        num_frames = 16,
         channels = 3,
+        num_frames = 16,
         exts = ['gif']
     ):
         super().__init__()
@@ -689,6 +689,8 @@ class Trainer(object):
         *,
         ema_decay = 0.995,
         image_size = 128,
+        channels = 3,
+        num_frames = 16,
         train_batch_size = 32,
         train_lr = 2e-5,
         train_num_steps = 100000,
@@ -713,7 +715,7 @@ class Trainer(object):
         self.gradient_accumulate_every = gradient_accumulate_every
         self.train_num_steps = train_num_steps
 
-        self.ds = Dataset(folder, image_size)
+        self.ds = Dataset(folder, image_size, channels = channels, num_frames = num_frames)
         self.dl = cycle(data.DataLoader(self.ds, batch_size = train_batch_size, shuffle=True, pin_memory=True))
         self.opt = Adam(diffusion_model.parameters(), lr=train_lr)
 
